---
title: Habitat 0.53.0 Released!
date: 2018-02-05
author: Tasha Drew
tags: release notes
category: release notes
classes: body-article
---

We are happy to announce the release of Habitat 0.53.0. We have a number of new features as well as bug fixes, so please read on for all the details. If you just want the binaries, head on over to our [https://www.habitat.sh/docs/using-habitat/#install-habitat](downloads page). Thanks again for using Habitat!

## Release Notes Highlights:

* Run Habitat as non-root
* **Potentially breaking change, depending on how you've automated your build pipeline** New Tar Exporter: slightly different command, includes the Habitat Launcher package by default
* Habitat and Windows: read all about it!
* Powershell 6.0 released: Update Windows Launcher and Supervisor
* Released: `hab plan init --windows`
* Habitat Launcher: new version released, please update
* Github Project re-organization
* New Docs: [Getting Started: Node.js & Habitat](https://www.habitat.sh/get-started/node/)
* Windows Developers/Release Engineers: Windows documentation for Habitat is now at parity in all our tutorials! [Get started here.](https://www.habitat.sh/docs/install-habitat/#install-habitat)

Please note: these release notes and deeper dives into the features over the next few days will all be available in more blog posts.

## Run Habitat as non-root

Historically, the Habitat Supervisor on Linux has always required `root` privileges to run. When running workloads on scheduler platforms like Kubernetes and OpenShift, however, it is not always desirable, or perhaps even possible, to run containers as `root`. This has made it impossible to run Habitat-built containers in a vanilla OpenShift installation, for example. With this release of the Habitat Supervisor, however, the need to run as `root` has been removed. The
Supervisor will continue to operate as it always has if it is run as `root`, but it can now modify its behavior when run as a user with lower privileges. This unlocks Habitat usage for a wider variety of users and use-cases.

* Supervisor should not require root [\#4525](https://github.com/habitat-sh/habitat/pull/4525)

## **Potentially breaking change** New Tar Exporter: slightly different command, includes hab launcher by default

Need to export your Habitat package as a tar archive?  We’ve just released a new tar exporter! The tar archives contain everything needed to run the package - including Habitat itself and all dependencies.  Although Habitat had an existing tar exporter, it was written in bash (which made it difficult if not impossible to use on Windows) and did not include the Habitat Launcher package, which is required to launch the Supervisor and dependent services.  This release includes a rewrite of the tar exporter in Rust - which makes it much more usable across platforms - and adds in a launcher to every tar export.  To export a hart package as a tar archive, run

```shell
$ hab pkg export tar origin/package_name
```

Then, upload it to wherever you wish to run it.  Unpackage it to your root filesystem with

```shell
$ sudo tar xf your_tar.tar.gz -C /
```

Then add in the hab group and user

```shell
$ sudo adduser --group hab
$ sudo useradd -g hab hab
```

Then, to run your package as a service, just run

```shell
$ sudo /hab/bin/hab start origin/package_name
```

Your service and all dependencies will be running!

* Tar Exporter - The Next Generation [\#4468](https://github.com/habitat-sh/habitat/pull/4468)

## Powershell 6.0 released: Update Windows Launcher and Supervisor

Powershell Core 6.0 has been officially released and the latest Windows Supervisor updates its dependency to use it. Powershell Core 6.0 changed the binary name of Powershell to pwsh.exe. In order to ensure that run hooks launched by the Windows Supervisor version 0.53.0 and later use the pwsh.exe binary, you will want to update your Habitat Launcher process. This is as simple as running “hab pkg install core/hab-launcher” on the same machine that is running the Supervisor. This Launcher is compatible with older Supervisors so it is advisable to update the launcher prior to updating the Supervisor.

* fallback to older powershell binary name if newer one is not installed [\#4540](https://github.com/habitat-sh/habitat/pull/4540

## Released: `hab plan init --windows`

Habitat’s “plan init” command can now generate Powershell based plans. Use the `--windows` flag to generate a plan.ps1 file instead of a plan.sh file with `hab plan init --windows <your_pkg_name>`.

- Implement `hab plan init` for Powershell plans [\#4527](https://github.com/habitat-sh/habitat/issues/4527)
- adding a `--windows option` for `hab plan init` to generate powershell plan [\#4528](https://github.com/habitat-sh/habitat/pull/4528)

## Habitat Launcher: new version released, please update

This release of Habitat includes a new release of the Launcher, a small binary that the Supervisor uses to help manage its supervised processes. Whereas the Supervisor is able to automatically update itself, the Launcher is currently released a bit differently, by design; it should be rare that the Launcher ever needs to change. To update your Launchers, you will need to run `hab pkg install core/hab-launcher` on each machine that has a Supervisor, and then restart your Supervisor. This will, by necessity, require a restart of supervised services, so factor that into your planning.

While we always recommend using the latest code, this Launcher is of particular interest for the following two use cases:  

If you wish to run the Supervisor on Linux as a non-root user _that is anonymous_ (i.e., has no named entry in `/etc/passwd`), you will need the new Launcher. (Note that container exports will automatically include the latest version of the Launcher with no additional actions on your part.)

On the other hand, if you are on Windows, you will also need the new Launcher, since the 0.53.0 Supervisor uses Powershell 6.0.0 and older Launchers will not invoke the newly-renamed `pwsh.exe` binary and therefore call the system installed version of Powershell instead of the Habitat packaged Powershell.

If neither scenario applies to you, updating the Launcher is not strictly required at this time, but please plan to update at your earliest convenience.

## Github Project Re-organization

Our Changelog is less useful than normal this release because we've reached the stage of project where it's time to split components into their own repos - so there are a bunch of issues that have been closed in the habitat-sh/habitat repo, and recreated in a more specific repo (e.g. habitat-sh/builder). You can see all the current repos here - [https://github.com/habitat-sh](https://github.com/habitat-sh/) - and don't hesitate to ask questions via Github Issues, the [Habitat Slack](http://slack.habitat.sh/), or [Twitter](https://twitter.com/habitatsh).

# Habitat CHANGELOG

## [0.53.0](https://github.com/habitat-sh/habitat/tree/0.53.0) (02-05-2018)
[Full Changelog](https://github.com/habitat-sh/habitat/compare/0.52.0...0.53.0)

## Features & Enhancements

- Implement `hab plan init` for Powershell plans [\#4527](https://github.com/habitat-sh/habitat/issues/4527)
- Add UI support for personal access tokens [\#4526](https://github.com/habitat-sh/habitat/issues/4526)
- Document running travis workflow locally [\#4472](https://github.com/habitat-sh/habitat/issues/4472)
- Fix builder dev studio [\#4442](https://github.com/habitat-sh/habitat/issues/4442)
- Mirror Live environment to acceptance [\#4240](https://github.com/habitat-sh/habitat/issues/4240)
- Getting started guides: Node  [\#4185](https://github.com/habitat-sh/habitat/issues/4185)
- Local Habitat environment [\#4117](https://github.com/habitat-sh/habitat/issues/4117)
- Builder Services Development Environment docs need updating [\#4070](https://github.com/habitat-sh/habitat/issues/4070)
- Instruct users to reload after installing the app in the plan connect view [\#3631](https://github.com/habitat-sh/habitat/issues/3631)
- List origin projects and provide a way to navigate to them [\#3579](https://github.com/habitat-sh/habitat/issues/3579)
- \[builder-worker\] Clean up `job.root\(\)/dockerd` directory on teardown. [\#3484](https://github.com/habitat-sh/habitat/issues/3484)
- Provide a way to find where files exist in packages found in the Depot [\#3465](https://github.com/habitat-sh/habitat/issues/3465)
- Fill in Dockerhub description fields [\#3456](https://github.com/habitat-sh/habitat/issues/3456)
- Reverse dependency lists and private packages [\#3409](https://github.com/habitat-sh/habitat/issues/3409)
- fix hab plan build for kubernetes exporter [\#4532](https://github.com/habitat-sh/habitat/pull/4532) ([mwrock](https://github.com/mwrock))
- Plan docs [\#4518](https://github.com/habitat-sh/habitat/pull/4518) ([mwrock](https://github.com/mwrock))
- expand zip file by default in Invoke-Unpack [\#4511](https://github.com/habitat-sh/habitat/pull/4511) ([mwrock](https://github.com/mwrock))
- rename powershell binary to new pwsh.exe [\#4495](https://github.com/habitat-sh/habitat/pull/4495) ([mwrock](https://github.com/mwrock))

## Bug fixes

- Worker builds hang when running with debug error logging [\#4483](https://github.com/habitat-sh/habitat/issues/4483)
- setting pkg\_svc\_run in powershell plans does not trigger run [\#4479](https://github.com/habitat-sh/habitat/issues/4479)
- \[builder-worker\] Ensure that parent directory for networking namespace is created initially. [\#4471](https://github.com/habitat-sh/habitat/issues/4471)
- \[builder-web\] XML Parsing error in Firefox [\#4440](https://github.com/habitat-sh/habitat/issues/4440)
- Docker image export not working? [\#4418](https://github.com/habitat-sh/habitat/issues/4418)
- Builder webhook - fix case where plan file is in a "habitat" folder [\#4323](https://github.com/habitat-sh/habitat/issues/4323)
- Builds from web UI and CLI behave differently [\#4317](https://github.com/habitat-sh/habitat/issues/4317)
- Docker tags not honored during publish [\#4274](https://github.com/habitat-sh/habitat/issues/4274)
- Users should not be able to enter an email address into integration field for docker hub [\#4206](https://github.com/habitat-sh/habitat/issues/4206)
- \[STABILITY\] \[Supervisor\] build worker crash in live - missing hab file uploaded file. [\#4012](https://github.com/habitat-sh/habitat/issues/4012)
- Navigating to a package which doesn't exist should ideally show the 404 page. [\#3966](https://github.com/habitat-sh/habitat/issues/3966)
- BLDR Service reports build failure when building sample-rails-app [\#3850](https://github.com/habitat-sh/habitat/issues/3850)
- Un-sharded services \(eg, job server\) should be able to route properly [\#3787](https://github.com/habitat-sh/habitat/issues/3787)
- Want long search results  [\#3728](https://github.com/habitat-sh/habitat/issues/3728)
- lingering origin invite [\#3727](https://github.com/habitat-sh/habitat/issues/3727)
- Reverse dependency lists and private packages [\#3409](https://github.com/habitat-sh/habitat/issues/3409)
- Add builder-base-plan back [\#4524](https://github.com/habitat-sh/habitat/pull/4524) ([christophermaier](https://github.com/christophermaier))
-  \[builder-worker\] Ensure parent network NS directory is created. [\#4473](https://github.com/habitat-sh/habitat/pull/4473) ([fnichol](https://github.com/fnichol))

**Merged pull requests:**

- Non-root Supervisor lands in 0.53.0, not 0.54.0 [\#4545](https://github.com/habitat-sh/habitat/pull/4545) ([christophermaier](https://github.com/christophermaier))
- fallback to older powershell binary name if newer one is not installed [\#4540](https://github.com/habitat-sh/habitat/pull/4540) ([mwrock](https://github.com/mwrock))
- Remove all the references to bin/haproxy & clarify docs [\#4533](https://github.com/habitat-sh/habitat/pull/4533) ([onlyhavecans](https://github.com/onlyhavecans))
- adding a --windows option for hab plan init to generate powershell plan [\#4528](https://github.com/habitat-sh/habitat/pull/4528) ([mwrock](https://github.com/mwrock))
- Supervisor should not require root [\#4525](https://github.com/habitat-sh/habitat/pull/4525) ([christophermaier](https://github.com/christophermaier))
- fix regression breaking docker exporter on windows [\#4517](https://github.com/habitat-sh/habitat/pull/4517) ([mwrock](https://github.com/mwrock))
- Make ubuntu latest officially-supported environment [\#4516](https://github.com/habitat-sh/habitat/pull/4516) ([baumanj](https://github.com/baumanj))
- Update ubuntu latest docs [\#4515](https://github.com/habitat-sh/habitat/pull/4515) ([baumanj](https://github.com/baumanj))
- Remove dead link [\#4514](https://github.com/habitat-sh/habitat/pull/4514) ([baumanj](https://github.com/baumanj))
- Documentation/note overriding scaffolding phases [\#4510](https://github.com/habitat-sh/habitat/pull/4510) ([onlyhavecans](https://github.com/onlyhavecans))
- Add back the launcher-protocol crate [\#4509](https://github.com/habitat-sh/habitat/pull/4509) ([raskchanky](https://github.com/raskchanky))
- Add the github requirements to the setup command [\#4507](https://github.com/habitat-sh/habitat/pull/4507) ([onlyhavecans](https://github.com/onlyhavecans))
- update cli, install and supervisor docs to provide windows specific info [\#4503](https://github.com/habitat-sh/habitat/pull/4503) ([mwrock](https://github.com/mwrock))
- Kubernetes & docker exporter fixes [\#4498](https://github.com/habitat-sh/habitat/pull/4498) ([zeenix](https://github.com/zeenix))
- Remove files that were used exclusively to run builder [\#4489](https://github.com/habitat-sh/habitat/pull/4489) ([elliott-davis](https://github.com/elliott-davis))
- fix pkg\_svc\_run behavior in powershell plans [\#4486](https://github.com/habitat-sh/habitat/pull/4486) ([mwrock](https://github.com/mwrock))
- Fix the GitHub button styling [\#4482](https://github.com/habitat-sh/habitat/pull/4482) ([cnunciato](https://github.com/cnunciato))
- Drop a file with unused code [\#4481](https://github.com/habitat-sh/habitat/pull/4481) ([krnowak](https://github.com/krnowak))
- add runtime environment evaluation to ps1 plan [\#4478](https://github.com/habitat-sh/habitat/pull/4478) ([mwrock](https://github.com/mwrock))
- Add Search Packages link to global website nav [\#4474](https://github.com/habitat-sh/habitat/pull/4474) ([ryankeairns](https://github.com/ryankeairns))
- Fix typo in studio README [\#4470](https://github.com/habitat-sh/habitat/pull/4470) ([themightychris](https://github.com/themightychris))
- Tar Exporter - The Next Generation [\#4468](https://github.com/habitat-sh/habitat/pull/4468) ([nellshamrell](https://github.com/nellshamrell))
- align windows bintray and blder versions and add some clarification to release doc [\#4467](https://github.com/habitat-sh/habitat/pull/4467) ([mwrock](https://github.com/mwrock))
- bump to 0.53.0-dev [\#4466](https://github.com/habitat-sh/habitat/pull/4466) ([mwrock](https://github.com/mwrock))
- adding Getting Started with Node blog post [\#4464](https://github.com/habitat-sh/habitat/pull/4464) ([mgamini](https://github.com/mgamini))
- Removing builder from the main repo [\#4452](https://github.com/habitat-sh/habitat/pull/4452) ([raskchanky](https://github.com/raskchanky))
- Docs/test additions to k8s exporter & various fixes [\#4448](https://github.com/habitat-sh/habitat/pull/4448) ([zeenix](https://github.com/zeenix))
- Adding node getting started guide [\#4424](https://github.com/habitat-sh/habitat/pull/4424) ([mgamini](https://github.com/mgamini))
